wagoe.audience.schema

Malli schemas for the wagoe-audience library. All internal data uses kebab-case keywords. snake_case conversion happens only at DB boundaries.

Malli schemas for the wagoe-audience library.
All internal data uses kebab-case keywords.
snake_case conversion happens only at DB boundaries.
raw docstring

AudienceDefinitionclj

source

CacheConfigclj

source

Composableclj

source

DynamicAudienceDefinitionclj

Stricter variant of AudienceDefinition — no fn values allowed in filters. Use this schema when persisting audience definitions to the database.

Stricter variant of AudienceDefinition — no fn values allowed in filters.
Use this schema when persisting audience definitions to the database.
sourceraw docstring

DynamicFilterDefclj

Like FilterDef but rejects fn values for :value (safe for DB persistence).

Like FilterDef but rejects fn values for :value (safe for DB persistence).
sourceraw docstring

FilterDefclj

source

MembershipRecordclj

source

SegmentRefclj

source

SegmentResultclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries